@@ -1,7 +1,15 @@
+from __future__ import unicode_literals
+from __future__ import print_function
+from __future__ import division
+from __future__ import absolute_import
+from future import standard_library
+standard_library.install_aliases()
+from builtins import *
+from builtins import object
 from mapr.ojai.storage.OJAIConnection import OJAIConnection
 
 
-class ConnectionFactory:
+class ConnectionFactory(object):
 
     def __init__(self):
         pass
